struct Inner {
state: State,
last_write_err: Option<ErrorKind>,
pos: u64,
}Fields
state: Statelast_write_err: Option<ErrorKind>Errors from writes/flushes are returned in write/flush calls. If a write error is observed while performing a read, it is saved until the next write / flush call.
pos: u64Implementations
Sourceimpl Inner
impl Inner
fn poll_read_inner( std: Arc<StdFile>, buf: Buf, max_buf_size: usize, ) -> Result<JoinHandle<(Operation, Buf)>>
fn spawn_blocking_read( buf: Buf, std: Arc<StdFile>, max_buf_size: usize, ) -> JoinHandle<(Operation, Buf)> ⓘ
async fn complete_inflight(&mut self)
fn poll_complete_inflight(&mut self, cx: &mut Context<'_>) -> Poll<()>
fn poll_flush(&mut self, cx: &mut Context<'_>) -> Poll<Result<(), Error>>